@@ -6,8 +6,9 @@ to_data_frame <- function(x, n = length(x)) {
   )
 }
 
+#' @rdname man-gho
 #' @export
-print.gho <- function(x, n = 6, ...) {
+print.gho <- function(x, n = options()$rgho.n, ...) {
   if (n == Inf) {
     n <- length(x)
   }
